/**
 * EasyBeans
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IAnnotationHandler.java 4124 2008-10-06 13:57:27Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.annotation.processor;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.Method;

/**
 * An {@link IAnnotationHandler} is responsible to do something
 * when a particular annotation is found.
 * @author Guillaume Sauthier
 */
public interface IAnnotationHandler {

	/**
	 * Declares that a given type of annotation is supported by this handler.
	 * @param clazz an annotation's type
	 * @return <code>true</code> if this handler supports the given annotation's type.
	 */
	boolean isSupported(Class<? extends Annotation> clazz);

	/**
	 * Process a class level annotation.
	 * This method is called by the processor when a supported annotation
	 * is found on a {@link Class}.
	 * @param annotation the found annotation
	 * @param clazz the class that supports the given annotation
	 * @param target target instance
	 * @throws ProcessorException
	 */
	void process(Annotation annotation, Class<?> clazz, Object target) throws ProcessorException;

	/**
	 * Process a method level annotation.
	 * This method is called by the processor when a supported annotation
	 * is found on a {@link Method}.
	 * @param annotation the found annotation
	 * @param method the method that supports the given annotation
	 * @param target target instance
	 * @throws ProcessorException
	 */
	void process(Annotation annotation, Method method, Object target) throws ProcessorException;

	/**
	 * Process a field level annotation.
	 * This method is called by the processor when a supported annotation
	 * is found on a {@link Field}.
	 * @param annotation the found annotation
	 * @param field the field that supports the given annotation
	 * @param target target instance
	 * @throws ProcessorException
	 */
	void process(Annotation annotation, Field field, Object target) throws ProcessorException;
}
